@@ -3,7 +3,7 @@ package Text::Table::Span;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-02-19'; # DATE
 our $DIST = 'Text-Table-Span'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -121,7 +121,7 @@ sub generate_table {
             my $exptable_colnum = firstidx {!defined} @{ $exptable->[$rownum] };
             #say "D:rownum=$rownum, exptable_colnum=$exptable_colnum";
             if ($exptable_colnum == -1) { $exptable_colnum = 0 }
-            $exptable_bottom_borders->[$rownum] //= $args{row_separator} ? 1:0;
+            $exptable_bottom_borders->[$rownum] //= $args{separate_rows} ? 1:0;
 
             for my $cell (@$row) {
                 $colnum++;
@@ -449,7 +449,7 @@ Text::Table::Span - Text::Table::Tiny + support for column/row spans
 
 =head1 VERSION
 
-This document describes version 0.004 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-19.
+This document describes version 0.005 of Text::Table::Span (from Perl distribution Text-Table-Span), released on 2021-02-19.
 
 =head1 SYNOPSIS
 
@@ -671,7 +671,7 @@ for the list of known attributes.
 Alternatively, you can specify a cell's attribute in the L</rows> argument
 directly, by specifying a cell as hashref.
 
-=item * row_separator
+=item * separate_rows
 
 Boolean. Optional. Default 0. If set to true, will add a separator between data
 rows. Equivalent to setting C<bottom_border> or C<top_border> attribute for each
